@@ -246,29 +246,29 @@ test_that("miscellaneous", {
   
   a <- HierarchyCompute(x, list(age = ageHier, geo = geoHier, year = "rowFactor"), "y", inputInOutput = TRUE, reduceData = FALSE, reOrder = TRUE, output = "matrixComponents")
   b <- Hierarchies2ModelMatrix(x, list(age = ageHier, geo = geoHier, year = "rowFactor"))
-  expect_identical(a$dataDummyHierarchy, t(b))
+  expect_identical(a$dataDummyHierarchy, Matrix::t(b))
   a <- HierarchyCompute(x, list(age = ageHier, geo = geoHier, year = "rowFactor"), y2, inputInOutput = TRUE, reduceData = FALSE, reOrder = TRUE, output = "matrixComponents")
-  expect_identical(a$dataDummyHierarchy, t(b))
+  expect_identical(a$dataDummyHierarchy, Matrix::t(b))
   
   z <- SSBtoolsData("sprt_emp")
   ageGeoYearFactor <- list(age = "", geo = "", year = "")
   
   m1 <- HierarchiesAndFormula2ModelMatrix(z, ageGeoYearFactor, ~geo * age + year:geo)
   m2 <- Formula2ModelMatrix(z, ~geo * age + year:geo)
-  expect_identical(t(m1), t(m2))  # t is trick that removes new attributes 
+  expect_identical(Matrix::t(m1), Matrix::t(m2))  # t is trick that removes new attributes 
   
   m1 <- HierarchiesAndFormula2ModelMatrix(x, ageGeoYearFactor, ~geo * age + year:geo)
   m2 <- Formula2ModelMatrix(x, ~geo * age + year:geo)
   m3 <- HierarchiesAndFormula2ModelMatrix(x, ageGeoYearFactor, ~geo * age + year:geo, removeEmpty = TRUE)
-  m1 = m1[ ,colSums(abs(m1))!=0]
-  expect_identical(t(m1), t(m2))
-  expect_identical(t(m1), t(m3))
+  m1 = m1[ ,Matrix::colSums(abs(m1))!=0]
+  expect_identical(Matrix::t(m1), Matrix::t(m2))
+  expect_identical(Matrix::t(m1), Matrix::t(m3))
   
   m1 <- Hierarchies2ModelMatrix(x, ageGeoYearFactor, select = "removeEmpty")
   m2 <- Formula2ModelMatrix(x, ~age:geo:year - 1, sep=":")
   m3 <- Hierarchies2ModelMatrix(x, ageGeoYearFactor, removeEmpty = TRUE)
-  expect_identical(t(m1), t(m2))
-  expect_identical(t(m1), t(m3))
+  expect_identical(Matrix::t(m1), Matrix::t(m2))
+  expect_identical(Matrix::t(m1), Matrix::t(m3))
   
   ageGeoYearTotal <- list(age = "Total", geo = "Total", year = "Total")
   m1 <- Hierarchies2ModelMatrix(x, ageGeoYearTotal, select = "removeEmpty")
